@@ -21,7 +21,7 @@ proxies = {
   "https": None,
 }
 
-## Variables - Nexus
+# Variables - Nexus
 nexus_format = ''
 artifact_name = ''
 work_directory = ''
@@ -34,7 +34,13 @@ password = ''
 directory = ''
 group_id = ''
 auth = ''
-## Variables - Nexus
+# Variables - Nexus
+
+# Variables - Deploy AWX
+encoded_string = ''  
+url = ''
+debug = 0
+# Variables - Deploy AWX
 
 
 def main(argv):  
@@ -42,9 +48,9 @@ def main(argv):
     action = ''
     
     ## Variables - Deploy AWX
-    encoded_string = ''  
-    url = ''
-    debug = 0
+    global encoded_string 
+    global url
+    global debug
     ## Variables - Deploy AWX
     
     ## Variables - Nexus
